@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Async::Util;
-$Search::Elasticsearch::Async::Util::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Async::Util::VERSION = '6.8001';use Moo;
+$Search::Elasticsearch::Async::Util::VERSION = '6.80';
+use Moo;
 use Scalar::Util qw(blessed);
 use Sub::Exporter -setup => { exports => ['thenable'] };
 
@@ -30,7 +29,7 @@ Search::Elasticsearch::Async::Util - A utility class for internal use by Elastic
 
 =head1 VERSION
 
-version 6.80_01
+version 6.80
 
 =head1 AUTHOR
 
