@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Cxn::AEHTTP;
-$Search::Elasticsearch::Cxn::AEHTTP::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Cxn::AEHTTP::VERSION = '6.8001';use AnyEvent::HTTP qw(http_request);
+$Search::Elasticsearch::Cxn::AEHTTP::VERSION = '6.80';
+use AnyEvent::HTTP qw(http_request);
 use Promises qw(deferred);
 use Try::Tiny;
 use Moo;
@@ -96,7 +95,7 @@ Search::Elasticsearch::Cxn::AEHTTP - An async Cxn implementation which uses AnyE
 
 =head1 VERSION
 
-version 6.80_01
+version 6.80
 
 =head1 DESCRIPTION
 
