@@ -1,7 +1,6 @@
 package Search::Elasticsearch::CxnPool::Async::Sniff;
-$Search::Elasticsearch::CxnPool::Async::Sniff::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::CxnPool::Async::Sniff::VERSION = '6.801';use Moo;
+$Search::Elasticsearch::CxnPool::Async::Sniff::VERSION = '6.80';
+use Moo;
 with 'Search::Elasticsearch::Role::CxnPool::Sniff',
     'Search::Elasticsearch::Role::Is_Async';
 
@@ -142,7 +141,7 @@ Search::Elasticsearch::CxnPool::Async::Sniff - An async CxnPool for connecting t
 
 =head1 VERSION
 
-version 6.80_1
+version 6.80
 
 =head1 SYNOPSIS
 
