@@ -1,7 +1,6 @@
 package Search::Elasticsearch::CxnPool::Async::Static;
-$Search::Elasticsearch::CxnPool::Async::Static::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::CxnPool::Async::Static::VERSION = '6.8001';use Moo;
+$Search::Elasticsearch::CxnPool::Async::Static::VERSION = '6.80';
+use Moo;
 with 'Search::Elasticsearch::Role::CxnPool::Static',
     'Search::Elasticsearch::Role::Is_Async';
 
@@ -82,7 +81,7 @@ Search::Elasticsearch::CxnPool::Async::Static - An async CxnPool for connecting
 
 =head1 VERSION
 
-version 6.80_01
+version 6.80
 
 =head1 SYNOPSIS
 
