@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Role::Cxn::Async;
-$Search::Elasticsearch::Role::Cxn::Async::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::Role::Cxn::Async::VERSION = '6.801';use Moo::Role;
+$Search::Elasticsearch::Role::Cxn::Async::VERSION = '6.80';
+use Moo::Role;
 
 use Search::Elasticsearch::Util qw(new_error);
 use namespace::clean;
@@ -66,7 +65,7 @@ Search::Elasticsearch::Role::Cxn::Async - Provides common functionality to async
 
 =head1 VERSION
 
-version 6.80_1
+version 6.80
 
 =head1 DESCRIPTION
 
