@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Transport::Async;
-$Search::Elasticsearch::Transport::Async::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::Transport::Async::VERSION = '6.801';use Moo;
+$Search::Elasticsearch::Transport::Async::VERSION = '6.80';
+use Moo;
 with 'Search::Elasticsearch::Role::Is_Async',
     'Search::Elasticsearch::Role::Transport';
 
@@ -87,7 +86,7 @@ Search::Elasticsearch::Transport::Async - Provides async interface between the c
 
 =head1 VERSION
 
-version 6.80_1
+version 6.80
 
 =head1 DESCRIPTION
 
